==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_taskeditpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<form method=post action=/project/<?= $project_name ?>/task/taskupdate.php>
<input type="hidden" name="task_id" value="<?= $task["task_id"] ?>">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">The following task was created by <b><?= getMemberName($task["created_by"]) ?></b> on <?= date("F d, Y",strtotime($task["date_created"])) ?>:</font><br><br></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Task:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $task["task_name"] ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Owner:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="assigned_to">
	<option value="">Nobody</option>
	<?
	    while(list($id,$name) = @each($project_members)) {
	        if($task["assigned_to"] == $id) {
	            $found = "yes";
	            $selected = " SELECTED";
	        } else { $selected = ""; }
	        echo "	<option value=\"$id\"$selected>$name</option>\n";
	    }
	    if($found != "yes" && !empty($task["assigned_to"])) {
	        echo "	<option value=\"" . $task["assigned_to"] . "\" SELECTED>" . getMemberName($task["assigned_to"]) . "</option>\n";
	    }
	 ?>
	</select>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Start Date:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" size="10" name="start_date" value="<?= date("m/d/Y",strtotime($task["start_date"])) ?>">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; 10/01/2000 (MM/DD/YYYY)</i></font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>End Date:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" size="10" name="end_date" value="<?= date("m/d/Y",strtotime($task["end_date"])) ?>">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; 10/01/2000 (MM/DD/YYYY)</i></font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Estimated Completion Time:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="10" name="hours" value="<?= $task["hours"] ?>"><font face="<?= $font_1 ?>" size="2">&nbsp;hours</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Progress:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="3" name="percent_done" value="<?= $task["percent_done"] ?>"><font face="<?= $font_1 ?>" size="2">&nbsp;%</font>
<br><font face="<?= $font_1 ?>" size="2"><i>(1-100)</i></font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Status:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="status_id">
	<?
	    while(list($id,$name) = @each($status_list)) {
	        if($task["status_id"] == $id) {
	            $selected = " SELECTED";
	        } else { $selected = ""; }
                $n_name = $name["name"] . (!empty($name["desc"])?" (".$name["desc"].")":"");
	        echo "    <option value=\"$id\"$selected>$n_name</option>\n";
	    }
	 ?>
	 </select>
 </td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Status Key:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2"><i>
Submitted = Initial status of all bugs upon submission<br>
Assigned = A team member has been assigned to resolving this bug<br>
Open = The bug has been verified and will be fixed at some point<br>
Resolved = Solution found, not yet implemented<br>
Closed = The bug is fixed
</i></font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Priority:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="priority">
	<option value="1">1</option>
	<option value="2">2</option>
	<option value="3">3</option>
	<option value="4">4</option>
	<option value="5">5</option>
	</select>
<br><font face="<?= $font_1 ?>" size="2">(5 being the highest priority)</font>
</td>
</tr>
<tr>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><b>Comments/Description:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="comments" rows="10" cols="40" WRAP><?= $task["comments"] ?></textarea></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Update Task"></td>
</tr>
</form>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_taskeditpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<form method=post action=/project/<?= $project_name ?>/task/taskupdate.php>
<input type="hidden" name="task_id" value="<?= $task["task_id"] ?>">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">The following task was created by <b><?= getMemberName($task["created_by"]) ?></b> on <?= date("F d, Y",strtotime($task["date_created"])) ?>:</font><br><br></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Task:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $task["task_name"] ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Owner:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="assigned_to">
	<option value="">Nobody</option>
	<?
	    while(list($id,$name) = @each($project_members)) {
	        if($task["assigned_to"] == $id) {
	            $found = "yes";
	            $selected = " SELECTED";
	        } else { $selected = ""; }
	        echo "	<option value=\"$id\"$selected>$name</option>\n";
	    }
	    if($found != "yes" && !empty($task["assigned_to"])) {
	        echo "	<option value=\"" . $task["assigned_to"] . "\" SELECTED>" . getMemberName($task["assigned_to"]) . "</option>\n";
	    }
	 ?>
	</select>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Start Date:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" size="10" name="start_date" value="<?= date("m/d/Y",strtotime($task["start_date"])) ?>">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; 10/01/2000 (MM/DD/YYYY)</i></font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>End Date:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" size="10" name="end_date" value="<?= date("m/d/Y",strtotime($task["end_date"])) ?>">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; 10/01/2000 (MM/DD/YYYY)</i></font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Estimated Completion Time:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="10" name="hours" value="<?= $task["hours"] ?>"><font face="<?= $font_1 ?>" size="2">&nbsp;hours</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Progress:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="3" name="percent_done" value="<?= $task["percent_done"] ?>"><font face="<?= $font_1 ?>" size="2">&nbsp;%</font>
<br><font face="<?= $font_1 ?>" size="2"><i>(1-100)</i></font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Status:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="status_id">
	<?
	    while(list($id,$name) = @each($status_list)) {
	        if($task["status_id"] == $id) {
	            $selected = " SELECTED";
	        } else { $selected = ""; }
                $n_name = $name["name"] . (!empty($name["desc"])?" (".$name["desc"].")":"");
	        echo "    <option value=\"$id\"$selected>$n_name</option>\n";
	    }
	 ?>
	 </select>
 </td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Status Key:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2"><i>
Submitted = Initial status of all bugs upon submission<br>
Assigned = A team member has been assigned to resolving this bug<br>
Open = The bug has been verified and will be fixed at some point<br>
Resolved = Solution found, not yet implemented<br>
Closed = The bug is fixed
</i></font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Priority:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
	<select name="priority">
	<option value="1"<?= ($task["priority"]==1?" SELECTED":"") ?>>1</option>
	<option value="2"<?= ($task["priority"]==2?" SELECTED":"") ?>>2</option>
	<option value="3"<?= ($task["priority"]==3?" SELECTED":"") ?>>3</option>
	<option value="4"<?= ($task["priority"]==4?" SELECTED":"") ?>>4</option>
	<option value="5"<?= ($task["priority"]==5?" SELECTED":"") ?>>5</option>
	</select>
<br><font face="<?= $font_1 ?>" size="2">(5 being the highest priority)</font>
</td>
</tr>
<tr>
<td valign="top"><font face="<?= $font_1 ?>" size="2"><b>Comments/Description:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="comments" rows="10" cols="40" WRAP><?= $task["comments"] ?></textarea></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Update Task"></td>
</tr>
</form>
</table>
